diff --git a/product/ERP5Banking/tests/TestERP5BankingMixin.py b/product/ERP5Banking/tests/TestERP5BankingMixin.py
index 60cc4a20073987e4a63fdd48ed6ce00a25a91a12..efe983a4f2f017cd838d0157b28c1faa04b39606 100644
--- a/product/ERP5Banking/tests/TestERP5BankingMixin.py
+++ b/product/ERP5Banking/tests/TestERP5BankingMixin.py
@@ -237,10 +237,16 @@ class TestERP5BankingMixin:
 
   def getCheckbookUsualCashTransferModule(self):
     """
     Return the Checkbook Vault Transfer Module
     """
     return getattr(self.getPortal(), 'checkbook_usual_cash_transfer_module', None)
 
+  def getCheckbookDeliveryModule(self):
+    """
+    Return the Checkbook Vault Transfer Module
+    """
+    return getattr(self.getPortal(), 'checkbook_delivery_module', None)
+
   def getCheckbookMovementModule(self):
     """
     Return the Checkbook Movement Module
@@ -237,10 +237,16 @@ class TestERP5BankingMixin:
   def getCheckbookUsualCashTransferModule(self):
     """
-    Return the Checkbook Vault Transfer Module
+    Return the Checkbook Delivery Module
     """
     return getattr(self.getPortal(), 'checkbook_usual_cash_transfer_module', None)